****************
Scientific goals
****************

.. image:: CAMELS_diagram.png


In order to maximize the scientific return of cosmological missions such as CMB-S4, DESI, eROSITA, Euclid, Roman Observatory, Rubin Observatory, Simons Observatory, PFS, and SKA, accurate theoretical predictions in the non-linear regime, for generic statistics, are needed. Furthermore, these predictions need to incorporate the uncertainity associated to our poor knowledge of baryonic effects such as AGN feedback. 

CAMELS is a large suite of N-body and state-of-the-art (magneto-)hydrodynamic simulations designed to tackle this problem. At its core, CAMELS represents a large dataset to train machine learning algorithms. The main scientific goals of CAMELS are these:

- Provide theory predictions for summary statistics and full 3D fields as a function of cosmology and astrophysics.

- Train neural networks to extract cosmological information while marginalizing over baryonic effects.

- Develop machine learning techniques to find the mapping between N-body simulations and hydrodynamic simulations with full baryonic physics.

- Quantify the dependence of galaxy formation and evolution on astrophysical and cosmological parameters.

- Use machine learning to efficiently calibrate subgrid parameters in cosmological hydrodynamic simulations to match a set of observations.
